from swanboard.db import (
    Project,
    Experiment,
    Tag,
    Chart,
    Namespace,
    Source,
    Display,
)
from tutils import create_test_dir
import nanoid


class TestProject:

    def test_init(self):
        name = nanoid.generate(size=10)
        p = Project.init(name)
        assert p.name == name


class TestExperiment:

    def test_create(self):
        pass


class TestTag:

    def test_create(self):
        pass


class TestChart:

    def test_create(self):
        pass


class TestNamespace:

    def test_create(self):
        pass


class TestSource:

    def test_create(self):
        pass


class TestDisplay:

    def test_create(self):
        pass



#!/usr/bin/env python
# -*- coding: utf-8 -*-
r"""
@DATE: 2024-02-29 14:34:29
@File: swanlab/db/migrate/exp_finish_time.py
@IDE: vscode
@Description:
    为数据库的Experiment表添加finish_time字段，用于记录实验结束时间
    实验结束时间是指实验被标记为完成/崩溃的时间
"""

from peewee import SqliteDatabase, CharField, IntegerField
from playhouse.migrate import migrate, SqliteMigrator


def add_finish_time(db):
    """
    为数据库的Experoment表添加finish_time字段,用于记录实验结束时间
    默认值为当前行的update_time
    """
    migrator = SqliteMigrator(db)
    finish_time = CharField(max_length=30, null=True, default=None)
    migrate(migrator.add_column("experiment", "finish_time", finish_time))
    # 原子化操作，遍历所有status不为0的实验，将其finish_time设置为update_time
    for exp in db.execute_sql("select id, update_time from experiment where status != 0"):
        db.execute_sql(f"update experiment set finish_time = '{exp[1]}' where id = {exp[0]}")


def add_pinned_opened(db):
    """
    为数据库的Experiment表添加pinned_opened字段,用于记录实验置顶部分是否打开
    默认值为1，表示打开
    """
    migrator = SqliteMigrator(db)
    pinned_opened = IntegerField(default=1, choices=[0, 1])
    migrate(migrator.add_column("experiment", "pinned_opened", pinned_opened))


def add_hidden_opened(db):
    """
    为数据库的Experiment表添加hidden_opened字段,用于记录实验隐藏部分是否打开
    默认值为0,表示关闭
    """
    migrator = SqliteMigrator(db)
    hidden_opened = IntegerField(default=0, choices=[0, 1])
    migrate(migrator.add_column("experiment", "hidden_opened", hidden_opened))



#!/usr/bin/env python
# -*- coding: utf-8 -*-
r"""
@DATE: 2024-02-19 15:41:25
@File: swanlab/db/migrate/__init__.py
@IDE: vscode
@Description:
    数据库迁移模块
"""
from .tag import add_sort
from .experiment import add_finish_time
from .namespace import add_opened
from .chart import add_status



#!/usr/bin/env python
# -*- coding: utf-8 -*-
r"""
@DATE: 2024-06-15 15:50:00
@File: swanboard/utils/package.py
@IDE: vscode
@Description:
    包相关的工具函数
"""
import os
import json


def get_package_version() -> str:
    """获取swanlab的版本号

    Parameters
    ----------
    p : str, optional
        package.json文件路径，默认为项目的package.json

    Returns
    -------
    str
        swanlab的版本号
    """
    path = os.path.join(os.path.dirname(os.path.dirname(__file__)), "package.json")
    # 读取package.json文件
    with open(path, "r") as f:
        return json.load(f)["version"]



from swanboard.db import connect, tables
from tutils import create_test_dir
import os
import shutil
import pytest


class TestConnectDB:
    @pytest.fixture(scope="class")
    def setup_before_class(self):
        pass

    def test_create_db(self):
        path = create_test_dir("test_for_connect")
        connect(path, autocreate=True)
        # 在path下有 run.swanlab 文件
        assert os.path.exists(os.path.join(path, "runs.swanlab"))
        if os.path.exists(path):
            shutil.rmtree(path)

    def test_create_tables(self):
        """测试是否自动创建数据表"""
        path = create_test_dir("test_for_connect")
        db = connect(path, autocreate=True)
        # 在数据库中有各个数据表
        for table in tables:
            assert db.table_exists(table)
        if os.path.exists(path):
            shutil.rmtree(path)
